@@ -1,4 +1,4 @@
 from .audiosystem import ULAudioSystem  # noqa
+from .audiosystem import set_master_volume  # noqa
 from .sound import ULSound2D  # noqa
 from .sound import ULSound3D  # noqa
-from .sound import ULSound  # noqa
